#
# spec file for package ghc-zlib
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%global pkg_name zlib

%bcond_with tests

Name:           ghc-zlib
Version:        0.6.1.1
Release:        2.4
Summary:        Compression and decompression in the gzip and zlib formats
Group:          System/Libraries

License:        BSD-2-Clause
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
# Begin cabal-rpm deps:
BuildRequires:  ghc-bytestring-devel
BuildRequires:  zlib-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-quickcheck-devel
%endif
# End cabal-rpm deps

%description
This package provides a pure interface for compressing and decompressing
streams of data represented as lazy 'ByteString's. It uses the zlib C library
so it has high performance. It supports the "zlib", "gzip" and "raw"
compression formats.

It provides a convenient high level API suitable for most tasks and for the few
cases where more control is needed it provides access to the full zlib feature
set.


%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}
Requires:       %{name} = %{version}-%{release}
# Begin cabal-rpm deps:
Requires:       zlib-devel
# End cabal-rpm deps

%description devel
This package provides the Haskell %{pkg_name} library development files.


%prep
%setup -q -n %{pkg_name}-%{version}


%build
%ghc_lib_build


%install
%ghc_lib_install


%check
%if %{with tests}
%cabal test
%endif


%post devel
%ghc_pkg_recache


%postun devel
%ghc_pkg_recache


%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE


%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc examples


%changelog
* Wed Dec 30 2015 mimi.vx@gmail.com
- update to 0.6.1.1
- regenerated spec file with cabal-rpm
  * Support for concatenated gzip files (multiple back-to-back streams)
  * Fixed warnings with new GHC
  * Fixed testsuite
  * New incremental interface for compression and decompression
  * Provide access to unconsumed trailing data
  * Simplified structured error type, and instance of Exception
  * Fixed memory leak of zlib z_stream C structure
  * More derivied instances (Eq, Show, Typeable, Generic)
* Sat Apr 11 2015 mimi.vx@gmail.com
- update to 0.5.4.2
  * no upstreqm changelog
* Fri Sep 12 2014 peter.trommler@ohm-hochschule.de
- update copyright notice (year) in spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- update to 0.5.4.1
  * no changelog
- part of Haskell Platform 2013.2 update
- more transparent packaging (fewer macros)
* Thu Dec 27 2012 peter.trommler@ohm-hochschule.de
- fix license tag (intentionally empty 3rd clause)
- expand macro in name tag (help factory-auto)
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Tue Oct  2 2012 peter.trommler@ohm-hochschule.de
- update to 0.5.4.0 from upstream (no changelog)
- required by Haskell Platform 2012.4.0.0
* Mon Jun  4 2012 peter.trommler@ohm-hochschule.de
- update to 0.5.3.3 from upstream (no changelog)
- required by Haskell Platform 2012.2.0.0
* Thu Feb 23 2012 peter.trommler@ohm-hochschule.de
- Added BuildRoot for sle11-sp1
* Thu Dec 15 2011 peter.trommler@ohm-hochschule.de
- Added requires zlib-devel
* Thu Dec 15 2011 peter.trommler@ohm-hochschule.de
- Add arches for OBS.
* Thu Dec 15 2011 peter.trommler@ohm-hochschule.de
- Initial packaging.
